@@ -35,6 +35,7 @@ def handle_item(config: dict, item: str, data: dict, used_textures: set|None = N
 		used_textures	(set):		The set to add used textures to (if any)
 		ignore_textures	(bool):		Whether to ignore textures or not (default: False, only used for the heavy workbench for NBT recipes)
 	"""
+	# Initialize variables
 	block_or_item: str = "item"
 	if data.get("id") == CUSTOM_BLOCK_VANILLA or any("block" in x for x in data.get(OVERRIDE_MODEL, {}).values()):
 		block_or_item = "block"
@@ -168,15 +169,21 @@ def handle_item(config: dict, item: str, data: dict, used_textures: set|None = N
 		else:
 			dump: str = "{}\n"
 		write_to_file(f"{dest_base_model}/{item}{on_off}.json", dump)
-
+		if data.get("item_model"):
+			config['rendered_item_models'].append(data["item_model"])
 
 
 def main(config: dict):
+	namespace: str = config['namespace']
+	config['rendered_item_models'] = []
 
 	# For each item,
 	used_textures = set()
 	for item, data in config['database'].items():
-		handle_item(config, item, data, used_textures)
+		if data.get("item_model") not in config['rendered_item_models']:
+			item_model: str = data.get("item_model", "")
+			if item_model.startswith(namespace):
+				handle_item(config, item, data, used_textures)
 
 	# Make warning for missing textures
 	warns = []
